package de.intevation.flys.artifacts.model.sq;

import org.apache.log4j.Logger;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;


import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.artifacts.model.CalculationResult;
import de.intevation.flys.artifacts.model.DataFacet;
import de.intevation.flys.artifacts.model.FacetTypes;

import de.intevation.flys.artifacts.states.DefaultState.ComputeType;


/**
 * Facet to show the curve in a sq relation.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class SQOutlierFacet extends DataFacet implements FacetTypes {

    private static final Logger log = Logger.getLogger(SQOutlierFacet.class);


    private int iteration;


    public SQOutlierFacet() {
    }


    public SQOutlierFacet(
        int    idx,
        int    iteration,
        String name,
        String description,
        String hash,
        String stateId
    ) {
        super(idx, name, description, ComputeType.ADVANCE, hash, stateId);
    }


    @Override
    public Object getData(Artifact artifact, CallContext context) {
        log.debug("SQOutlierFacet.getData");

        if (artifact instanceof FLYSArtifact) {
            FLYSArtifact flys = (FLYSArtifact) artifact;

            CalculationResult res = (CalculationResult) flys.compute(
                context, ComputeType.ADVANCE, false);

            SQResult[] result = (SQResult[]) res.getData();

            return result[index].getOutliers(iteration);
        }

        return null;
    }


    @Override
    public SQOutlierFacet deepCopy() {
        SQOutlierFacet copy = new SQOutlierFacet();
        copy.set(this);

        return copy;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
